@@ -1,4 +1,4 @@
-/*  $Id: Controller.h,v 1.2 2010/05/26 03:13:01 sarrazip Exp $
+/*  $Id: Controller.h,v 1.3 2024/04/08 03:43:38 sarrazip Exp $
     Controller.h - Control of the game's main character
 
     burgerspace - A hamburger-smashing video game.
@@ -33,7 +33,7 @@ class Controller
 {
 public:
 
-    Controller(SDLKey pepperKey)
+    Controller(SDL_Keycode pepperKey)
       : startKS(SDLK_SPACE),
         pauseKS(SDLK_p),
         quitKS(SDLK_ESCAPE),
@@ -52,7 +52,7 @@ public:
     {
     }
 
-    void check(SDLKey keysym, bool pressed)
+    void check(SDL_Keycode keysym, bool pressed)
     {
         startKS.check(keysym, pressed);
         pauseKS.check(keysym, pressed);
