@@ -1,4 +1,4 @@
-/*  $Id: IngredientSprite.h,v 1.12 2010/05/26 03:13:01 sarrazip Exp $
+/*  $Id: IngredientSprite.h,v 1.13 2017/12/09 04:29:00 sarrazip Exp $
     IngredientSprite.h - Sprite that is part of an "ingredient"
 
     burgerspace - A hamburger-smashing video game.
@@ -42,7 +42,7 @@ public:
 
     IngredientSprite(const flatzebra::PixmapArray &pixmapArray,
                         const flatzebra::Couple &pos,
-                        IngredientGroup *ig) throw(int)
+                        IngredientGroup *ig)
       : flatzebra::Sprite(pixmapArray, pos,
                 flatzebra::Couple(0, 0), flatzebra::Couple(0, 0),
                 flatzebra::Couple(0, 5), flatzebra::Couple(24, 1)),
