@@ -1,4 +1,4 @@
-/*  $Id: util.h,v 1.3 2010/09/16 03:22:22 sarrazip Exp $
+/*  $Id: util.h,v 1.4 2024/04/08 03:43:40 sarrazip Exp $
     util.h - Miscellaneous definitions.
 
     burgerspace - A hamburger-smashing video game.
@@ -25,6 +25,7 @@
 
 #include <string>
 #include <stdlib.h>
+#include <stdint.h>
 
 #ifndef _MSC_VER
 #include <sys/socket.h>
@@ -54,42 +55,6 @@ enum
 };
 
 
-// Network-related constants.
-enum
-{
-    MAX_LEN_PACKET = 1024,
-    UPDATE_SPRITE_PACKET_LEN = 12
-};
-
-
-enum ServerPacketType
-{
-    UPDATE_LEVEL_PACKET,
-    UPDATE_SPRITE_PACKET,
-    UPDATE_SCORE_PACKET,
-    PLAY_SOUND_EFFECT_PACKET,
-    ROLE_ASSIGNMENT_PACKET
-};
-
-
-enum ClientPacketType
-{
-    CLIENT_DESC_PACKET,
-    START_NEW_GAME_PACKET,
-    LEVEL_DESC_REQUEST_PACKET,
-    PLAYER_COMMAND_PACKET,
-    DISCONNECT_PACKET
-};
-
-
-enum Role
-{
-    ROLE_SPECTATOR,
-    ROLE_CHEF,
-    ROLE_ENEMY
-};
-
-
 enum EnemyType
 {
     ENEMY_EGG,
